Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/windirstat/walkdir.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAndrew Gallant <jamslam@gmail.com>2017-10-21 04:34:26 +0300
committerAndrew Gallant <jamslam@gmail.com>2017-10-21 15:10:18 +0300
commit9c4adadc4fcb79baa721b2c7f8f88688024e3b1e (patch)
treec9ea57c1c9f270e0a39908682040931c49a4c827
parentbc0ff47394875e31e098e88b36f7711a5fb26fa1 (diff)
symlink: rename symbolic_link to symlink
Fixes #80
-rw-r--r--src/lib.rs11
1 files changed, 7 insertions, 4 deletions
diff --git a/src/lib.rs b/src/lib.rs
index 7a24469..c3da203 100644
--- a/src/lib.rs
+++ b/src/lib.rs
@@ -1,4 +1,3 @@
-#![doc(html_root_url = "https://docs.rs/walkdir/1.0.7")]
/*!
Crate `walkdir` provides an efficient and cross platform implementation
of recursive directory traversal. Several options are exposed to control
@@ -102,6 +101,10 @@ for entry in walker.filter_entry(|e| !is_hidden(e)) {
[`filter_entry`]: struct.IntoIter.html#method.filter_entry
*/
+
+#![doc(html_root_url = "https://docs.rs/walkdir/1.0.7")]
+#![deny(missing_docs)]
+
#[cfg(windows)] extern crate kernel32;
#[cfg(windows)] extern crate winapi;
#[cfg(test)] extern crate quickcheck;
@@ -856,12 +859,12 @@ impl DirEntry {
///
/// Note that this *always* returns the path reported by the underlying
/// directory entry, even when symbolic links are followed. To get the
/// target path, use [`path_is_symbolic_link`] to (cheaply) check if
/// this entry corresponds to a symbolic link, and [`std::fs::read_link`] to
/// resolve the target.
///
/// [`WalkDir::new`]: struct.WalkDir.html#method.new
- /// [`path_is_symbolic_link`]: struct.DirEntry.html#method.path_is_symbolic_link
+ /// [`path_is_symlink`]: struct.DirEntry.html#method.path_is_symlink
/// [`std::fs::read_link`]: https://doc.rust-lang.org/stable/std/fs/fn.read_link.html
pub fn path(&self) -> &Path {
&self.path
@@ -877,7 +880,7 @@ impl DirEntry {
/// [`path`]: struct.DirEntry.html#method.path
/// [`follow_links`]: struct.WalkDir.html#method.follow_links
/// [`std::fs::read_link(entry.path())`]: https://doc.rust-lang.org/stable/std/fs/fn.read_link.html
- pub fn path_is_symbolic_link(&self) -> bool {
+ pub fn path_is_symlink(&self) -> bool {
self.ty.is_symlink() || self.follow_link
}
@@ -856,12 +859,12 @@ impl DirEntry {
/// Note that this *always* returns the path reported by the underlying
/// directory entry, even when symbolic links are followed. To get the
- /// target path, use [`path_is_symbolic_link`] to (cheaply) check if
+ /// target path, use [`path_is_symlink`] to (cheaply) check if
/// this entry corresponds to a symbolic link, and [`std::fs::read_link`] to
/// resolve the target.